@@ -1,7 +1,7 @@
 /*
  * Copyright 2005-2006 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/main.c,v 1.131 2007/01/07 17:47:41 solar Exp $
+ * $Header: /var/cvsroot/gentoo-projects/portage-utils/main.c,v 1.135 2007/03/16 21:31:11 solar Exp $
  *
  * Copyright 2005-2006 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2006 Mike Frysinger  - <vapier@gentoo.org>
@@ -95,10 +95,10 @@ static char config_protect[_Q_PATH_MAX] = "/etc/";
 char pkgdir[512] = "/usr/portage/packages/";
 char port_tmpdir[512] = "/var/tmp/portage/";
 
-char binhost[512] = PORTAGE_BINHOST;
-char features[512] = "noman noinfo nodoc";
+char binhost[1024] = PORTAGE_BINHOST;
+char features[2048] = "noman noinfo nodoc";
 char accept_license[512] = "*";
-char install_mask[1024] = "";
+char install_mask[BUFSIZ] = "";
 
 const char *err_noapplet = "Sorry this applet was disabled at compile time";
 
@@ -434,6 +434,10 @@ char *strincr_var(const char *name, char *s, char *value, const size_t value_len
 	char buf[BUFSIZ];
 	char *p;
 
+
+	if ((strlen(value) + 1 + strlen(s)) >= value_len)
+		errf("%s will exceed max length value of %d with a size of %d", name, value_len, (strlen(value) + 1 + strlen(s)));
+
 	strncat(value, " ", value_len);
 	strncat(value, s, value_len);
 
@@ -505,6 +509,7 @@ void initialize_portage_env(void)
 	f = 0;
 	if (readlink("/etc/make.profile", profile, sizeof(profile)) == -1)
 		strcpy(profile, "/etc/make.profile");
+	chdir("/etc");
 	do {
 		if (f == 0)
 			snprintf(portage_file, sizeof(portage_file), "%s/make.defaults", profile);
@@ -650,7 +655,13 @@ const char *initialize_flat(int cache_type)
 	}
 
 	if ((fp = fopen(cache_file, "w")) == NULL) {
-		warnfp("opening '%s/%s' failed", portdir, cache_file);
+		if (cache_type == CACHE_EBUILD)
+			warnfp("opening '%s/%s' failed", portdir, cache_file);
+		else
+			warnfp("opening '%s/%s/%s' failed", portdir, portcachedir, cache_file);
+		if (errno == EACCES)
+			warnf("You should run this command as root: q -%c",
+					cache_type == CACHE_EBUILD ? 'r' : 'm');
 		goto ret;
 	}
 
@@ -762,6 +773,7 @@ typedef struct {
 	char *CDEPEND;
 	char *PDEPEND;
 	char *PROVIDE;       /* line 14 */
+	char *EAPI;
 	depend_atom *atom;
 } portage_cache;
 
@@ -863,6 +875,7 @@ portage_cache *cache_read_file(const char *file)
 	next_line(IUSE, CDEPEND)
 	next_line(CDEPEND, PDEPEND)
 	next_line(PDEPEND, PROVIDE)
+	next_line(PROVIDE, EAPI)
 #undef next_line
 	ptr = strchr(ptr+1, '\n');
 	*ptr = '\0';
@@ -896,6 +909,7 @@ void cache_dump(portage_cache *cache)
 	printf("CDEPEND    : %s\n", cache->CDEPEND);
 	printf("PDEPEND    : %s\n", cache->PDEPEND);
 	printf("PROVIDE    : %s\n", cache->PROVIDE);
+	printf("EAPI       : %s\n", cache->EAPI);
 	if (!cache->atom) return;
 	printf("CATEGORY   : %s\n", cache->atom->CATEGORY);
 	printf("PN         : %s\n", cache->atom->PN);
